import numpy as np
import pandas as pd
from scipy import signal

# Constants
ACC_FILE_PATH = './Accelerometer_turnleft.csv'
GYRO_FILE_PATH = './Gyroscope_turnleft.csv'
SAMPLING_FREQ = 100  # Hz
DT = 1 / SAMPLING_FREQ 

# 下記はpeekを検出
def search_peek_time(file_path):
    # 加速度センサデータのファイル読み込み
    df = pd.read_csv(file_path)
    df['norm'] = (df['x']**2 + df['y']**2 + df['z']**2)**0.5
    df['low_norm'] = df['norm'].rolling(window=10).mean()
    # ピークを検出
    peek, _ = signal.find_peaks(df['low_norm'], height=13)
    ## peekのtを取得
    peek_t = df['t'][peek]

    return np.round(peek_t,2)

# peek検出し画面に出力
if __name__ == '__main__':
    # ジャイロスコープセンサデータのファイル読み込み
    gyro_data = pd.read_csv(GYRO_FILE_PATH)
 
    # 't'列を除外したデータを取得
    gyro_data_no_t = gyro_data.drop(columns=['t'])
 
    # 'x', 'y', 'z'列のみを積分
    angle_data_no_t = np.cumsum(gyro_data_no_t * DT)
 
    # 積分したデータに't'列を結合
    angle_data = pd.concat([gyro_data['t'], angle_data_no_t], axis=1)
    angle_data['rounded_t'] = np.round(angle_data['t'], 2)
 
    # search_peek_time()のkeysを取得
    peek_t_values = search_peek_time(ACC_FILE_PATH).values
    angle_data_peek = angle_data[angle_data['rounded_t'].isin(peek_t_values)]
    angle_data_peek_x = angle_data_peek['z']

    print(angle_data_peek)